[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[GNUnet-SVN] [gnunet] branch master updated: NAMESTORE: rename flat plug
From: |
gnunet |
Subject: |
[GNUnet-SVN] [gnunet] branch master updated: NAMESTORE: rename flat plugin to heap |
Date: |
Mon, 15 Oct 2018 12:05:20 +0200 |
This is an automated email from the git hooks/post-receive script.
martin-schanzenbach pushed a commit to branch master
in repository gnunet.
The following commit(s) were added to refs/heads/master by this push:
new 116171c28 NAMESTORE: rename flat plugin to heap
116171c28 is described below
commit 116171c281ff6f301198ff9499d158995abaae51
Author: Schanzenbach, Martin <address@hidden>
AuthorDate: Mon Oct 15 19:05:11 2018 +0900
NAMESTORE: rename flat plugin to heap
---
src/namestore/Makefile.am | 128 ++++++++++-----------
src/namestore/namestore.conf.in | 4 +-
src/namestore/perf_namestore_api_flat.conf | 10 --
src/namestore/perf_namestore_api_heap.conf | 10 ++
...in_namestore_flat.c => plugin_namestore_heap.c} | 34 +++---
..._api_flat.conf => test_namestore_api_heap.conf} | 4 +-
...e_flat.conf => test_plugin_namestore_heap.conf} | 2 +-
7 files changed, 96 insertions(+), 96 deletions(-)
diff --git a/src/namestore/Makefile.am b/src/namestore/Makefile.am
index a349921d7..54357dd1e 100644
--- a/src/namestore/Makefile.am
+++ b/src/namestore/Makefile.am
@@ -20,26 +20,26 @@ if USE_COVERAGE
XLIBS = -lgcov
endif
-FLAT_PLUGIN = libgnunet_plugin_namestore_flat.la
+HEAP_PLUGIN = libgnunet_plugin_namestore_heap.la
if HAVE_TESTING
-FLAT_TESTS = test_plugin_namestore_flat \
- test_namestore_api_store_flat \
- test_namestore_api_store_update_flat \
- test_namestore_api_remove_flat \
- test_namestore_api_zone_iteration_flat \
- test_namestore_api_lookup_nick_flat \
- test_namestore_api_monitoring_flat \
- test_namestore_api_lookup_public_flat \
- test_namestore_api_lookup_private_flat \
- test_namestore_api_lookup_shadow_flat \
- test_namestore_api_lookup_shadow_filter_flat \
- test_namestore_api_remove_not_existing_record_flat \
- test_namestore_api_zone_iteration_nick_flat \
- test_namestore_api_zone_iteration_specific_zone_flat \
- test_namestore_api_zone_iteration_stop_flat \
- test_namestore_api_monitoring_existing_flat \
- test_namestore_api_zone_to_name_flat \
- perf_namestore_api_zone_iteration_flat
+HEAP_TESTS = test_plugin_namestore_heap \
+ test_namestore_api_store_heap \
+ test_namestore_api_store_update_heap \
+ test_namestore_api_remove_heap \
+ test_namestore_api_zone_iteration_heap \
+ test_namestore_api_lookup_nick_heap \
+ test_namestore_api_monitoring_heap \
+ test_namestore_api_lookup_public_heap \
+ test_namestore_api_lookup_private_heap \
+ test_namestore_api_lookup_shadow_heap \
+ test_namestore_api_lookup_shadow_filter_heap \
+ test_namestore_api_remove_not_existing_record_heap \
+ test_namestore_api_zone_iteration_nick_heap \
+ test_namestore_api_zone_iteration_specific_zone_heap \
+ test_namestore_api_zone_iteration_stop_heap \
+ test_namestore_api_monitoring_existing_heap \
+ test_namestore_api_zone_to_name_heap \
+ perf_namestore_api_zone_iteration_heap
endif
if HAVE_SQLITE
@@ -94,7 +94,7 @@ if HAVE_SQLITE
check_PROGRAMS = \
$(SQLITE_TESTS) \
$(POSTGRES_TESTS) \
- $(FLAT_TESTS)
+ $(HEAP_TESTS)
endif
if ENABLE_TEST_RUN
@@ -180,18 +180,18 @@ gnunet_service_namestore_LDADD = \
plugin_LTLIBRARIES = \
$(SQLITE_PLUGIN) \
$(POSTGRES_PLUGIN) \
- $(FLAT_PLUGIN)
+ $(HEAP_PLUGIN)
-libgnunet_plugin_namestore_flat_la_SOURCES = \
- plugin_namestore_flat.c
-libgnunet_plugin_namestore_flat_la_LIBADD = \
+libgnunet_plugin_namestore_heap_la_SOURCES = \
+ plugin_namestore_heap.c
+libgnunet_plugin_namestore_heap_la_LIBADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
$(top_builddir)/src/statistics/libgnunetstatistics.la \
$(top_builddir)/src/util/libgnunetutil.la $(XLIBS) \
$(LTLIBINTL)
-libgnunet_plugin_namestore_flat_la_LDFLAGS = \
+libgnunet_plugin_namestore_heap_la_LDFLAGS = \
$(GN_PLUGIN_LDFLAGS)
@@ -217,9 +217,9 @@ libgnunet_plugin_namestore_postgres_la_LIBADD = \
libgnunet_plugin_namestore_postgres_la_LDFLAGS = \
$(GN_PLUGIN_LDFLAGS) $(POSTGRESQL_LDFLAGS)
-test_namestore_api_store_flat_SOURCES = \
+test_namestore_api_store_heap_SOURCES = \
test_namestore_api_store.c
-test_namestore_api_store_flat_LDADD = \
+test_namestore_api_store_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -241,9 +241,9 @@ test_namestore_api_store_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_namestore_api_store_update_flat_SOURCES = \
+test_namestore_api_store_update_heap_SOURCES = \
test_namestore_api_store_update.c
-test_namestore_api_store_update_flat_LDADD = \
+test_namestore_api_store_update_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -268,9 +268,9 @@ test_namestore_api_store_update_postgres_LDADD = \
$(top_builddir)/src/namecache/libgnunetnamecache.la \
libgnunetnamestore.la
-test_namestore_api_lookup_public_flat_SOURCES = \
+test_namestore_api_lookup_public_heap_SOURCES = \
test_namestore_api_lookup_public.c
-test_namestore_api_lookup_public_flat_LDADD = \
+test_namestore_api_lookup_public_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -313,18 +313,18 @@ test_namestore_api_lookup_nick_postgres_LDADD = \
$(top_builddir)/src/namecache/libgnunetnamecache.la \
libgnunetnamestore.la
-test_namestore_api_lookup_nick_flat_SOURCES = \
+test_namestore_api_lookup_nick_heap_SOURCES = \
test_namestore_api_lookup_nick.c
-test_namestore_api_lookup_nick_flat_LDADD = \
+test_namestore_api_lookup_nick_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
$(top_builddir)/src/namecache/libgnunetnamecache.la \
libgnunetnamestore.la
-test_namestore_api_lookup_private_flat_SOURCES = \
+test_namestore_api_lookup_private_heap_SOURCES = \
test_namestore_api_lookup_private.c
-test_namestore_api_lookup_private_flat_LDADD = \
+test_namestore_api_lookup_private_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -349,9 +349,9 @@ test_namestore_api_lookup_private_postgres_LDADD = \
$(top_builddir)/src/namecache/libgnunetnamecache.la \
libgnunetnamestore.la
-test_namestore_api_lookup_shadow_flat_SOURCES = \
+test_namestore_api_lookup_shadow_heap_SOURCES = \
test_namestore_api_lookup_shadow.c
-test_namestore_api_lookup_shadow_flat_LDADD = \
+test_namestore_api_lookup_shadow_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -376,9 +376,9 @@ test_namestore_api_lookup_shadow_postgres_LDADD = \
$(top_builddir)/src/namecache/libgnunetnamecache.la \
libgnunetnamestore.la
-test_namestore_api_lookup_shadow_filter_flat_SOURCES = \
+test_namestore_api_lookup_shadow_filter_heap_SOURCES = \
test_namestore_api_lookup_shadow_filter.c
-test_namestore_api_lookup_shadow_filter_flat_LDADD = \
+test_namestore_api_lookup_shadow_filter_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -418,17 +418,17 @@ test_namestore_api_remove_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_namestore_api_remove_flat_SOURCES = \
+test_namestore_api_remove_heap_SOURCES = \
test_namestore_api_remove.c
-test_namestore_api_remove_flat_LDADD = \
+test_namestore_api_remove_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_namestore_api_remove_not_existing_record_flat_SOURCES = \
+test_namestore_api_remove_not_existing_record_heap_SOURCES = \
test_namestore_api_remove_not_existing_record.c
-test_namestore_api_remove_not_existing_record_flat_LDADD = \
+test_namestore_api_remove_not_existing_record_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -450,9 +450,9 @@
test_namestore_api_remove_not_existing_record_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_namestore_api_zone_to_name_flat_SOURCES = \
+test_namestore_api_zone_to_name_heap_SOURCES = \
test_namestore_api_zone_to_name.c
-test_namestore_api_zone_to_name_flat_LDADD = \
+test_namestore_api_zone_to_name_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
libgnunetnamestore.la
@@ -471,9 +471,9 @@ test_namestore_api_zone_to_name_postgres_LDADD = \
$(top_builddir)/src/util/libgnunetutil.la \
libgnunetnamestore.la
-test_namestore_api_monitoring_flat_SOURCES = \
+test_namestore_api_monitoring_heap_SOURCES = \
test_namestore_api_monitoring.c
-test_namestore_api_monitoring_flat_LDADD = \
+test_namestore_api_monitoring_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
libgnunetnamestore.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -495,9 +495,9 @@ test_namestore_api_monitoring_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
$(top_builddir)/src/util/libgnunetutil.la
-test_namestore_api_monitoring_existing_flat_SOURCES = \
+test_namestore_api_monitoring_existing_heap_SOURCES = \
test_namestore_api_monitoring_existing.c
-test_namestore_api_monitoring_existing_flat_LDADD = \
+test_namestore_api_monitoring_existing_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
libgnunetnamestore.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -519,9 +519,9 @@ test_namestore_api_monitoring_existing_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
$(top_builddir)/src/util/libgnunetutil.la
-test_namestore_api_zone_iteration_flat_SOURCES = \
+test_namestore_api_zone_iteration_heap_SOURCES = \
test_namestore_api_zone_iteration.c
-test_namestore_api_zone_iteration_flat_LDADD = \
+test_namestore_api_zone_iteration_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -559,17 +559,17 @@ perf_namestore_api_zone_iteration_sqlite_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-perf_namestore_api_zone_iteration_flat_SOURCES = \
+perf_namestore_api_zone_iteration_heap_SOURCES = \
perf_namestore_api_zone_iteration.c
-perf_namestore_api_zone_iteration_flat_LDADD = \
+perf_namestore_api_zone_iteration_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_namestore_api_zone_iteration_nick_flat_SOURCES = \
+test_namestore_api_zone_iteration_nick_heap_SOURCES = \
test_namestore_api_zone_iteration_nick.c
-test_namestore_api_zone_iteration_nick_flat_LDADD = \
+test_namestore_api_zone_iteration_nick_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -591,9 +591,9 @@ test_namestore_api_zone_iteration_nick_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_namestore_api_zone_iteration_specific_zone_flat_SOURCES = \
+test_namestore_api_zone_iteration_specific_zone_heap_SOURCES = \
test_namestore_api_zone_iteration_specific_zone.c
-test_namestore_api_zone_iteration_specific_zone_flat_LDADD = \
+test_namestore_api_zone_iteration_specific_zone_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -615,9 +615,9 @@
test_namestore_api_zone_iteration_specific_zone_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_namestore_api_zone_iteration_stop_flat_SOURCES = \
+test_namestore_api_zone_iteration_stop_heap_SOURCES = \
test_namestore_api_zone_iteration_stop.c
-test_namestore_api_zone_iteration_stop_flat_LDADD = \
+test_namestore_api_zone_iteration_stop_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
@@ -639,9 +639,9 @@ test_namestore_api_zone_iteration_stop_postgres_LDADD = \
$(top_builddir)/src/gnsrecord/libgnunetgnsrecord.la \
libgnunetnamestore.la
-test_plugin_namestore_flat_SOURCES = \
+test_plugin_namestore_heap_SOURCES = \
test_plugin_namestore.c
-test_plugin_namestore_flat_LDADD = \
+test_plugin_namestore_heap_LDADD = \
$(top_builddir)/src/testing/libgnunettesting.la \
$(top_builddir)/src/util/libgnunetutil.la
@@ -666,13 +666,13 @@ EXTRA_DIST = \
test_namestore_api.conf \
test_namestore_api_postgres.conf \
test_namestore_api_sqlite.conf \
- test_namestore_api_flat.conf \
+ test_namestore_api_heap.conf \
perf_namestore_api_postgres.conf \
perf_namestore_api_sqlite.conf \
- perf_namestore_api_flat.conf \
+ perf_namestore_api_heap.conf \
test_plugin_namestore_sqlite.conf \
test_plugin_namestore_postgres.conf \
- test_plugin_namestore_flat.conf \
+ test_plugin_namestore_heap.conf \
test_hostkey \
zonefiles/S5I9DSGQVAB5FVV16T3B3CC5H1B2JGL3Q412JBKURME8EKU0600G.zkey \
zonefiles/AQ835GVL939H4O8QJQ7GBLPTQC0QAAO91BN7QK01BA63MDSK6I4G.zkey \
diff --git a/src/namestore/namestore.conf.in b/src/namestore/namestore.conf.in
index eb95f95be..b5fb45abc 100644
--- a/src/namestore/namestore.conf.in
+++ b/src/namestore/namestore.conf.in
@@ -23,8 +23,8 @@ CACHE_KEYS = YES
[namestore-sqlite]
FILENAME = $GNUNET_DATA_HOME/namestore/sqlite.db
-[namestore-flat]
-FILENAME = $GNUNET_DATA_HOME/namestore/flat.db
+[namestore-heap]
+FILENAME = $GNUNET_DATA_HOME/namestore/heap.db
[namestore-postgres]
diff --git a/src/namestore/perf_namestore_api_flat.conf
b/src/namestore/perf_namestore_api_flat.conf
deleted file mode 100644
index f356e9061..000000000
--- a/src/namestore/perf_namestore_api_flat.conf
+++ /dev/null
@@ -1,10 +0,0 @@
address@hidden@ test_namestore_api.conf
-
-[namestore]
-DATABASE = flat
-
-[namecache]
-DISABLE = YES
-
-[namestore-flat]
-FILENAME = $GNUNET_TEST_HOME/namestore/flat.db
diff --git a/src/namestore/perf_namestore_api_heap.conf
b/src/namestore/perf_namestore_api_heap.conf
new file mode 100644
index 000000000..a12761a7f
--- /dev/null
+++ b/src/namestore/perf_namestore_api_heap.conf
@@ -0,0 +1,10 @@
address@hidden@ test_namestore_api.conf
+
+[namestore]
+DATABASE = heap
+
+[namecache]
+DISABLE = YES
+
+[namestore-heap]
+FILENAME = $GNUNET_TEST_HOME/namestore/heap.db
diff --git a/src/namestore/test_namestore_api_flat.conf
b/src/namestore/test_namestore_api_heap.conf
similarity index 74%
rename from src/namestore/test_namestore_api_flat.conf
rename to src/namestore/test_namestore_api_heap.conf
index 6a28306e3..1d6173e74 100644
--- a/src/namestore/test_namestore_api_flat.conf
+++ b/src/namestore/test_namestore_api_heap.conf
@@ -1,7 +1,7 @@
@INLINE@ test_namestore_api.conf
[namestore]
-DATABASE = flat
+DATABASE = heap
-[namestore-flat]
+[namestore-heap]
FILENAME = $GNUNET_TEST_HOME/namestore/flat.db
diff --git a/src/namestore/test_plugin_namestore_flat.conf
b/src/namestore/test_plugin_namestore_heap.conf
similarity index 79%
rename from src/namestore/test_plugin_namestore_flat.conf
rename to src/namestore/test_plugin_namestore_heap.conf
index 5c632f0d1..94f79b9aa 100644
--- a/src/namestore/test_plugin_namestore_flat.conf
+++ b/src/namestore/test_plugin_namestore_heap.conf
@@ -1,2 +1,2 @@
-[namestore-flat]
+[namestore-heap]
FILENAME = $GNUNET_TMP/gnunet-test-plugin-namestore-flat/flatdb
diff --git a/src/namestore/plugin_namestore_flat.c
b/src/namestore/plugin_namestore_heap.c
similarity index 96%
rename from src/namestore/plugin_namestore_flat.c
rename to src/namestore/plugin_namestore_heap.c
index 4873f6e51..8442294f7 100644
--- a/src/namestore/plugin_namestore_flat.c
+++ b/src/namestore/plugin_namestore_heap.c
@@ -17,7 +17,7 @@
*/
/**
- * @file namestore/plugin_namestore_flat.c
+ * @file namestore/plugin_namestore_heap.c
* @brief file-based namestore backend
* @author Martin Schanzenbach
* @author Christian Grothoff
@@ -109,12 +109,12 @@ database_setup (struct Plugin *plugin)
if (GNUNET_OK !=
GNUNET_CONFIGURATION_get_value_filename (plugin->cfg,
- "namestore-flat",
+ "namestore-heap",
"FILENAME",
&afsdir))
{
GNUNET_log_config_missing (GNUNET_ERROR_TYPE_ERROR,
- "namestore-flat",
+ "namestore-heap",
"FILENAME");
return GNUNET_SYSERR;
}
@@ -415,7 +415,7 @@ database_shutdown (struct Plugin *plugin)
* @return #GNUNET_OK on success, else #GNUNET_SYSERR
*/
static int
-namestore_flat_store_records (void *cls,
+namestore_heap_store_records (void *cls,
const struct GNUNET_CRYPTO_EcdsaPrivateKey
*zone_key,
const char *label,
unsigned int rd_count,
@@ -490,7 +490,7 @@ namestore_flat_store_records (void *cls,
* @return #GNUNET_OK on success, #GNUNET_NO for no results, else
#GNUNET_SYSERR
*/
static int
-namestore_flat_lookup_records (void *cls,
+namestore_heap_lookup_records (void *cls,
const struct GNUNET_CRYPTO_EcdsaPrivateKey
*zone,
const char *label,
GNUNET_NAMESTORE_RecordIterator iter,
@@ -576,7 +576,7 @@ struct IterateContext
/**
* Helper function for #namestore_flat_iterate_records().
*
* @param cls a `struct IterateContext`
* @param key unused
@@ -633,7 +633,7 @@ iterate_zones (void *cls,
* @return #GNUNET_OK on success, #GNUNET_NO if there were no more results,
#GNUNET_SYSERR on error
*/
static int
-namestore_flat_iterate_records (void *cls,
+namestore_heap_iterate_records (void *cls,
const struct GNUNET_CRYPTO_EcdsaPrivateKey
*zone,
uint64_t serial,
uint64_t limit,
@@ -717,7 +717,7 @@ zone_to_name (void *cls,
* @return #GNUNET_OK on success, #GNUNET_NO if there were no results,
#GNUNET_SYSERR on error
*/
static int
-namestore_flat_zone_to_name (void *cls,
+namestore_heap_zone_to_name (void *cls,
const struct GNUNET_CRYPTO_EcdsaPrivateKey *zone,
const struct GNUNET_CRYPTO_EcdsaPublicKey
*value_zone,
GNUNET_NAMESTORE_RecordIterator iter,
@@ -749,7 +749,7 @@ namestore_flat_zone_to_name (void *cls,
* @return NULL on error, otherwise the plugin context
*/
void *
-libgnunet_plugin_namestore_flat_init (void *cls)
+libgnunet_plugin_namestore_heap_init (void *cls)
{
static struct Plugin plugin;
const struct GNUNET_CONFIGURATION_Handle *cfg = cls;
@@ -768,12 +768,12 @@ libgnunet_plugin_namestore_flat_init (void *cls)
}
api = GNUNET_new (struct GNUNET_NAMESTORE_PluginFunctions);
api->cls = &plugin;
- api->store_records = &namestore_flat_store_records;
- api->iterate_records = &namestore_flat_iterate_records;
- api->zone_to_name = &namestore_flat_zone_to_name;
- api->lookup_records = &namestore_flat_lookup_records;
+ api->store_records = &namestore_heap_store_records;
+ api->iterate_records = &namestore_heap_iterate_records;
+ api->zone_to_name = &namestore_heap_zone_to_name;
+ api->lookup_records = &namestore_heap_lookup_records;
GNUNET_log (GNUNET_ERROR_TYPE_INFO,
- _("flat file database running\n"));
+ _("heap file database running\n"));
return api;
}
@@ -785,7 +785,7 @@ libgnunet_plugin_namestore_flat_init (void *cls)
* @return always NULL
*/
void *
-libgnunet_plugin_namestore_flat_done (void *cls)
+libgnunet_plugin_namestore_heap_done (void *cls)
{
struct GNUNET_NAMESTORE_PluginFunctions *api = cls;
struct Plugin *plugin = api->cls;
@@ -794,8 +794,8 @@ libgnunet_plugin_namestore_flat_done (void *cls)
plugin->cfg = NULL;
GNUNET_free (api);
GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
- "flat file plugin is finished\n");
+ "heap file plugin is finished\n");
return NULL;
}
-/* end of plugin_namestore_flat.c */
+/* end of plugin_namestore_heap.c */
@@ -576,7 +576,7 @@ struct IterateContext
/**
- * Helper function for #namestore_flat_iterate_records().
+ * Helper function for #namestore_heap_iterate_records().
*
* @param cls a `struct IterateContext`
--
To stop receiving notification emails like this one, please contact
address@hidden
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- [GNUnet-SVN] [gnunet] branch master updated: NAMESTORE: rename flat plugin to heap,
gnunet <=